<?php

namespace Litecms\WithdrawSettings\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\WithdrawSettings\Models\WithdrawSettings;

class WithdrawSettingsPolicy
{

    /**
     * Determine if the given user can view the withdraw_settings.
     *
     * @param UserPolicy $user
     * @param WithdrawSettings $withdraw_settings
     *
     * @return bool
     */
    public function view(UserPolicy $user, WithdrawSettings $withdraw_settings)
    {
        if ($user->canDo('withdraw_settings.withdraw_settings.view') && $user->isAdmin()) {
            return true;
        }

        return $withdraw_settings->user_id == user_id() && $withdraw_settings->user_type == user_type();
    }

    /**
     * Determine if the given user can create a withdraw_settings.
     *
     * @param UserPolicy $user
     * @param WithdrawSettings $withdraw_settings
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('withdraw_settings.withdraw_settings.create');
    }

    /**
     * Determine if the given user can update the given withdraw_settings.
     *
     * @param UserPolicy $user
     * @param WithdrawSettings $withdraw_settings
     *
     * @return bool
     */
    public function update(UserPolicy $user, WithdrawSettings $withdraw_settings)
    {
        if ($user->canDo('withdraw_settings.withdraw_settings.edit') && $user->isAdmin()) {
            return true;
        }

        return $withdraw_settings->user_id == user_id() && $withdraw_settings->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given withdraw_settings.
     *
     * @param UserPolicy $user
     * @param WithdrawSettings $withdraw_settings
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, WithdrawSettings $withdraw_settings)
    {
        return $withdraw_settings->user_id == user_id() && $withdraw_settings->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given withdraw_settings.
     *
     * @param UserPolicy $user
     * @param WithdrawSettings $withdraw_settings
     *
     * @return bool
     */
    public function verify(UserPolicy $user, WithdrawSettings $withdraw_settings)
    {
        if ($user->canDo('withdraw_settings.withdraw_settings.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given withdraw_settings.
     *
     * @param UserPolicy $user
     * @param WithdrawSettings $withdraw_settings
     *
     * @return bool
     */
    public function approve(UserPolicy $user, WithdrawSettings $withdraw_settings)
    {
        if ($user->canDo('withdraw_settings.withdraw_settings.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
